@@ -28,42 +28,53 @@ public:
 
     virtual ~CGaussian();
 
+	GBMRESULT UpdateParams(double *adF,
+	                       double *adOffset,
+						   double *adWeight,
+	                       unsigned long cLength)
+	{ 
+		return GBM_OK;
+	};
+
     GBMRESULT ComputeWorkingResponse(double *adY,
-                                   double *adMisc,
-                                   double *adOffset,
-                                   double *adWeight,
-                                   double *adF,
-                                   double *adZ,
-                                   bool *afInBag,
-                                   unsigned long nTrain);
+                                     double *adMisc,
+                                     double *adOffset,
+                                     double *adWeight,
+                                     double *adF,
+                                     double *adZ,
+                                     bool *afInBag,
+                                     unsigned long nTrain,
+	                                 int cIdxOff);
 
     GBMRESULT InitF(double *adY, 
-                  double *adMisc,
-                  double *adOffset,
-                  double *adWeight,
-                  double &dInitF, 
-                  unsigned long cLength);
+                    double *adMisc,
+                    double *adOffset,
+                    double *adWeight,
+                    double &dInitF, 
+                    unsigned long cLength);
 
     GBMRESULT FitBestConstant(double *adY,
-                            double *adMisc,
-                            double *adOffset,
-                            double *adW,
-                            double *adF,
-                            double *adZ,
-                            unsigned long *aiNodeAssign,
-                            unsigned long nTrain,
-                            VEC_P_NODETERMINAL vecpTermNodes,
-                            unsigned long cTermNodes,
-                            unsigned long cMinObsInNode,
-                            bool *afInBag,
-                            double *adFadj);
+                              double *adMisc,
+                              double *adOffset,
+                              double *adW,
+                              double *adF,
+                              double *adZ,
+                              unsigned long *aiNodeAssign,
+                              unsigned long nTrain,
+                              VEC_P_NODETERMINAL vecpTermNodes,
+                              unsigned long cTermNodes,
+                              unsigned long cMinObsInNode,
+                              bool *afInBag,
+                              double *adFadj,
+                           	  int cIdxOff);
 
     double Deviance(double *adY,
                     double *adMisc,
                     double *adOffset,
                     double *adWeight,
                     double *adF,
-                    unsigned long cLength);
+                    unsigned long cLength,
+	                int cIdxOff);
 
     double BagImprovement(double *adY,
                           double *adMisc,
